@@ -3,8 +3,8 @@
 import _curses
 
 import time
-from compot import MeasurementSpec, wrapper
-from compot.widgets import ProgressBar, Text
+from compot import LayoutSpec, MeasurementSpec, wrapper
+from compot.widgets import ProgressBar, Text, Row
 
 
 def __demo(stdscr: '_curses._CursesWindow') -> int:
@@ -27,6 +27,11 @@ def __demo(stdscr: '_curses._CursesWindow') -> int:
             measurement=MeasurementSpec.xywh(0, 0, bar_w, 1)
         ).build().render()
 
+        Row((ProgressBar(total_time / 10), ),
+            measurement=MeasurementSpec.xywh(0, 11, bar_w, 1),
+            layout=LayoutSpec.FILL
+        ).build().render()
+
         Text(
             f'FPS: {round(1 / render_time)}',
             measurement=MeasurementSpec.xywh(0, 10, bar_w, 1)
